==> HostCMS.Free_6.7.tar.gz: modules/shop/delivery/i18n/en.php <==
<?php
/**
 * Online shop.
 *
 * @package HostCMS
 * @subpackage Shop
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2017 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Delivery',
	'show_type_of_delivery_title' => 'Deliveries',
	'show_type_of_delivery_link' => 'Delivery',
	'show_type_of_delivery_link_add' => 'Add',
	'type_of_delivery_add_form_title' => 'Add delivery type information',
	'type_of_delivery_edit_form_title' => 'Edit delivery type information',
	'payment_systems' => 'Payment systems',
	'payment_systems_not_specified' => 'Payment systems are not specified',
	'name' => '<acronym title=\'Name of delivery type\'>Name</acronym>',
	'sorting' => 'Sort order',
	'active' => '<acronym title=\'Activity of delivery type\'>Active</acronym>',
	'description' => '<acronym title=\'Description of delivery type\'>Description</acronym>',
	'image' => '<acronym title=\'Image of delivery type\'>Image</acronym>',
	'id' => 'Id',
	'shop_id' => 'Shop id',
	'delivery' => "Delivery '%s'",
	'edit_success' => 'Delivery type information added successfully!',
	'edit_error' => 'Error while adding delivery type information!',
	'apply_success' => 'Information has been successfully changed',
	'copy_success' => 'Information has been copied successfully!',
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
	'markDeleted_success' => 'Delivery type information deleted successfully!',
	'changeStatus_success' => 'Information has been successfully changed',
	'option0' => 'Condition',
	'option1' => 'Formula',
	'handler' => 'Handler PHP-code',
	'method' => 'Delivery Method',
	'pickup' => 'Pickup',
	'post' => 'Post',
	'courier' => 'Courier',
	'days_from' => 'Delivery days from',
	'days_to' => 'to',
);

==> HostCMS.Free_7.0.tar.gz: modules/shop/delivery/i18n/en.php <==
<?php

return array(
	'model_name' => 'Delivery',
	'show_type_of_delivery_title' => 'Deliveries',
	'show_type_of_delivery_link' => 'Delivery',
	'show_type_of_delivery_link_add' => 'Add',
	'type_of_delivery_add_form_title' => 'Add delivery type information',
	'type_of_delivery_edit_form_title' => 'Edit delivery type information',
	'payment_systems' => 'Payment systems',
	'payment_systems_not_specified' => 'Payment systems are not specified',
	'name' => 'Name',
	'sorting' => 'Sort',
	'active' => 'Active',
	'description' => 'Description',
	'image' => 'Image',
	'id' => 'ID',
	'shop_id' => 'Shop id',
	'delivery' => "Delivery '%s'",
	'edit_success' => 'Delivery type information added successfully!',
	'edit_error' => 'Error while adding delivery type information!',
	'apply_success' => 'Information has been successfully changed',
	'copy_success' => 'Information has been copied successfully!',
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
	'markDeleted_success' => 'Delivery type information deleted successfully!',
	'changeStatus_success' => 'Information has been successfully changed',
	'option0' => 'Condition',
	'option1' => 'Formula',
	'handler' => 'Handler PHP-code',
	'method' => 'Delivery Method',
	'pickup' => 'Pickup',
	'post' => 'Post',
	'courier' => 'Courier',
	'days_from' => 'Delivery days from',
	'days_to' => 'to',
	'guid' => 'GUID',
	'delivery_with_condition' => 'Delivery of "%s: %s"',
	'conditions_for_delivery' => 'Delivery conditions for "%s"',
	'empty_conditions_for_delivery' => 'There are no delivery terms',
	'apply_button' => 'Apply',
	'intervals' => 'Intervals',
);
